==> geant4.9.6.p04.tar.gz: geant4.9.6.p04/examples/.doxygen/Doxymodules_medical.h <==
// $Id: Doxymodules_medical.h 65679 2012-11-26 13:41:53Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_medical.h
/// \brief The page that defines the extended/medical examples modules 


/** @defgroup extended_medical medical
 *  Extended medical examples classes
 *  @{
 */

/** @defgroup extended_medical_DICOM DICOM
 *  Medical example DICOM 
 *  @ingroup extended_medical
 *  @{
 */

  class DicomDetectorConstruction {};
  class DicomEventAction {};
  class DicomHandler {};
  class DicomIntersectVolume {};
  class DicomNestedParamDetectorConstruction {};
  class DicomNestedPhantomParameterisation {};
  class DicomPartialDetectorConstruction {};
  class DicomPhantomParameterisationColour {};
  class DicomPhantomZSliceHeader {};
  class DicomPhysicsList {};
  class DicomPrimaryGeneratorAction {};
  class DicomRegularDetectorConstruction {};
  class DicomRunAction {};
  class DicomRun {};
  class NestedParamDicomDetectorConstruction {};
  class RegularDicomDetectorConstruction {};

/** @} */

/** @} */

/** @defgroup extended_medical_electronScattering electronScattering
 *  Medical electronScattering example has its
 *  <a href="../html_electronScattering/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_electronScattering2 electronScattering2
 *  Medical electronScattering2 example has its
 *  <a href="../html_electronScattering2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity fanoCavity
 *  Medical fanoCavity example has its
 *  <a href="../html_fanoCavity/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity2 fanoCavity2
 *  Medical fanoCavity2 example has its
 *  <a href="../html_fanoCavity2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_GammaTherapy GammaTherapy
 *  Medical GammaTherapy example has its
 *  <a href="../html_GammaTherapy/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */


/** @} */

==> geant4.10.00.tar.gz: geant4.10.00/examples/.doxygen/Doxymodules_medical.h <==
// $Id: Doxymodules_medical.h 76473 2013-11-11 10:35:14Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_medical.h
/// \brief The page that defines the extended/medical examples modules 


/** @defgroup extended_medical medical
 *  Extended medical examples classes
 *  @{
 */

/** @defgroup extended_medical_DICOM DICOM
 *  Medical example DICOM 
 *  @ingroup extended_medical
 *  @{
 */

  class DicomActionInitialization {};
  class DicomDetectorConstruction {};
  class DicomEventAction {};
  class DicomHandler {};
  class DicomIntersectVolume {};
  class DicomNestedParamDetectorConstruction {};
  class DicomNestedPhantomParameterisation {};
  class DicomPartialDetectorConstruction {};
  class DicomPhantomParameterisationColour {};
  class DicomPhantomZSliceHeader {};
  class DicomPhantomZSliceMerged {};
  class DicomPhysicsList {};
  class DicomPrimaryGeneratorAction {};
  class DicomRegularDetectorConstruction {};
  class DicomRunAction {};
  class DicomRun {};

/** @} */

/** @} */

/** @defgroup extended_medical_electronScattering electronScattering
 *  Medical electronScattering example has its
 *  <a href="../html_electronScattering/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_electronScattering2 electronScattering2
 *  Medical electronScattering2 example has its
 *  <a href="../html_electronScattering2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity fanoCavity
 *  Medical fanoCavity example has its
 *  <a href="../html_fanoCavity/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_fanoCavity2 fanoCavity2
 *  Medical fanoCavity2 example has its
 *  <a href="../html_fanoCavity2/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */

/** @defgroup extended_medical_GammaTherapy GammaTherapy
 *  Medical GammaTherapy example has its
 *  <a href="../html_GammaTherapy/html/index.html">standalone documentation </a>
 *  @ingroup extended_medical
 *  @{
 */

/** @} */


/** @} */
